package com.vctgo.system.service;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.vctgo.system.api.domain.SysTenant;
import com.vctgo.system.domain.SysReServiceTenant;

import java.util.List;

/**
 * 服务与租户关联Service接口
 *
 * @author caesar
 * @date 2023-10-08
 */
public interface ISysReServiceTenantService extends IService<SysReServiceTenant> {
    /**
     * 查询服务与租户关联
     *
     * @param id 服务与租户关联主键
     * @return 服务与租户关联
     */
    SysReServiceTenant selectSysReServiceTenantById(Long id);

    /**
     * 查询服务与租户关联列表-分页
     *
     * @param sysReServiceTenant 服务与租户关联
     * @return 服务与租户关联集合
     */
    IPage<SysReServiceTenant> selectSysReServiceTenantPage(SysReServiceTenant sysReServiceTenant);

    /**
     * 查询服务与租户关联列表
     *
     * @param sysReServiceTenant 服务与租户关联
     * @return 服务与租户关联集合
     */
    List<SysReServiceTenant> selectSysReServiceTenantList(SysReServiceTenant sysReServiceTenant);

    /**
     * 新增服务与租户关联
     *
     * @param sysReServiceTenant 服务与租户关联
     * @return 结果
     */
    int insertSysReServiceTenant(SysReServiceTenant sysReServiceTenant);

    /**
     * 修改服务与租户关联
     *
     * @param sysReServiceTenant 服务与租户关联
     * @return 结果
     */
    int updateSysReServiceTenant(SysReServiceTenant sysReServiceTenant);

    /**
     * 逻辑删除服务与租户关联
     *
     * @param ids
     * @return 结果
     */
    int logicalDeleteSysReServiceTenantByIds(Long[] ids);

    /**
     * 批量删除服务与租户关联
     *
     * @param ids 需要删除的服务与租户关联主键集合
     * @return 结果
     */
    int deleteSysReServiceTenantByIds(Long[] ids);

    /**
     * 删除服务与租户关联信息
     *
     * @param id 服务与租户关联主键
     * @return 结果
     */
    int deleteSysReServiceTenantById(Long id);

    List<SysReServiceTenant> selectSysReServiceTenantListByTenantId(String tenantId);;
}
